If you use `penprs` in your research, please cite the following paper:

```bibtex

@article {Song2025.01.28.25321292,
	author = {Song, Junyi and Zabad, Shadi and Yang, Archer and Li, Yue},
	title = {Sparse Polygenic Risk Score Inference with the Spike-and-Slab LASSO},
	elocation-id = {2025.01.28.25321292},
	year = {2025},
	doi = {10.1101/2025.01.28.25321292},
	publisher = {Cold Spring Harbor Laboratory Press},
	URL = {https://www.medrxiv.org/content/early/2025/01/29/2025.01.28.25321292},
	eprint = {https://www.medrxiv.org/content/early/2025/01/29/2025.01.28.25321292.full.pdf},
	journal = {medRxiv}
}

```
